@@ -26,14 +26,14 @@ from xdg import BaseDirectory
 
 # Application constants
 APP_NAME = 'GNOME AppFolders Manager'
-APP_VERSION = '0.4.6'
+APP_VERSION = '0.4.7'
 APP_DESCRIPTION = 'Manage GNOME Shell applications folders'
 APP_DOMAIN = 'gnome-appfolders-manager'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
 APP_COPYRIGHT = f'Copyright 2016-2022 {APP_AUTHOR}'
 APP_ID = f'{APP_DOMAIN}.muflone.com'
-URL_AUTHOR = 'https://www.muflone.com/'
+URL_AUTHOR = 'http://www.muflone.com/'
 URL_APPLICATION = f'{URL_AUTHOR}{APP_DOMAIN}/'
 URL_SOURCES = f'https://github.com/muflone/{APP_DOMAIN}/'
 URL_TRANSLATIONS = f'https://explore.transifex.com/muflone/{APP_DOMAIN}/'
